@@ -6,7 +6,7 @@ BEGIN {
   $Dist::Zilla::Role::PrereqSource::External::AUTHORITY = 'cpan:KENTNL';
 }
 {
-  $Dist::Zilla::Role::PrereqSource::External::VERSION = '0.2.2';
+  $Dist::Zilla::Role::PrereqSource::External::VERSION = '0.2.3';
 }
 
 # FILENAME: External.pm
@@ -16,6 +16,7 @@ BEGIN {
 use Moose::Role;
 with 'Dist::Zilla::Role::Plugin';
 
+
 use namespace::autoclean;
 
 requires 'register_external_prereqs';
@@ -23,11 +24,11 @@ requires 'register_external_prereqs';
 no Moose::Role;
 1;
 
-
 __END__
+
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -35,7 +36,18 @@ Dist::Zilla::Role::PrereqSource::External - A plugin that depends on DarkPAN/Ext
 
 =head1 VERSION
 
-version 0.2.2
+version 0.2.3
+
+=begin MetaPOD::JSON v1.1.0
+
+{
+    "namespace":"Dist::Zilla::Role::PrereqSource::External",
+    "interface":"role",
+    "does":"Dist::Zilla::Role::Plugin"
+}
+
+
+=end MetaPOD::JSON
 
 =head1 AUTHOR
 
@@ -43,10 +55,9 @@ Kent Fredric <kentnl@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Kent Fredric <kentnl@cpan.org>.
+This software is copyright (c) 2013 by Kent Fredric <kentnl@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
